@@ -70,12 +70,15 @@ OC.L10N.register(
     "Upcoming cards" : "Nadcházející karty",
     "Personal" : "Osobní",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kartu „%s“ na „%s“ vám přiřadil(a) %s.",
-    "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} vám přiřadil(a) kartu „%s“ na „%s“.",
+    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} vám přiřadil(a) kartu {deck-card} na tabuli {deck-board}.",
     "The card \"%s\" on \"%s\" has reached its due date." : "U karty „%s“ z tabule „%s“ nastalo plánované datum dokončení.",
+    "The card {deck-card} on {deck-board} has reached its due date." : "Karta {deck-card} na tabuli {deck-board} dosáhla data plánovaného dokončení.",
     "%s has mentioned you in a comment on \"%s\"." : "%s vás zmínil(a) v komentáři k „%s“.",
-    "{user} has mentioned you in a comment on \"%s\"." : "{user} vás zmínil(a) v komentáři k „%s“.",
+    "{user} has mentioned you in a comment on {deck-card}." : "{user} vás zmínil(a) v komentáři na kartě {deck-card}.",
     "The board \"%s\" has been shared with you by %s." : "Uživatel %s vám nasdílel(a) tabuli „%s“.",
-    "{user} has shared the board %s with you." : "{user} vám nasdílel(a) tabuli %s.",
+    "{user} has shared {deck-board} with you." : "{user} s vámi sdílel(a) tabuli {deck-board}.",
+    "Card comments" : "Komentáře v kartách",
+    "%s on %s" : "%s na %s",
     "No data was provided to create an attachment." : "Nebyla poskytnuta žádná data pro vytvoření přílohy.",
     "Finished" : "Dokončeno",
     "To review" : "K revizi",
@@ -99,7 +102,7 @@ OC.L10N.register(
     "No file uploaded or file size exceeds maximum of %s" : "Nebyl nahrán žádný soubor nebo jeho velikost přesáhla %s",
     "Card not found" : "Karta nebyla nalezena",
     "Path is already shared with this card" : "Cesta je již s touto kartou sdílena",
-    "Invalid date, date format must be YYYY-MM-DD" : "Neplatné datum, formát data musí být RRRR-MM-DD",
+    "Invalid date, date format must be YYYY-MM-DD" : "Neplatné datum – je třeba, aby formát data byl RRRR-MM-DD",
     "Personal planning and team project organization" : "Osobní plánování a organizování týmového projektu",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck je nástroj cílený na osobní nebo projektové plánování týmů v Kanban stylu, vestavěný v Nextcloud.\n\n\n- 📥 Zadávejte a uspořádávejte své úkoly do karet\n- 📄 Zapisujte si dodatečné poznámky \n- 🔖 Přiřazujte štítky pro ještě lepší organizaci\n- 👥 Sdílejte se svým týmem, přáteli nebo rodinou\n- 🚀 Dostaňte svůj projekt pod kontrolu",
     "Card details" : "Podrobnosti o kartě",
@@ -112,8 +115,8 @@ OC.L10N.register(
     "Select a list" : "Vyberte sloupec",
     "Card title" : "Název karty",
     "Cancel" : "Storno",
-    "Creating the new card…" : "Vytváření nové karty…",
-    "\"{card}\" was added to \"{board}\"" : "„{card}“ bylo přidáno do „{board}“",
+    "Creating the new card …" : "Vytváření nové karty…",
+    "Card \"{card}\" was added to \"{board}\"" : "Karta „{card}“ byla přidána na „{board}“",
     "Open card" : "Otevřít kartu",
     "Close" : "Zavřít",
     "Create card" : "Vytvořit kartu",
@@ -188,7 +191,7 @@ OC.L10N.register(
     "Delete Attachment" : "Smazat přílohu",
     "Restore Attachment" : "Obnovit přílohu",
     "File to share" : "Soubor ke sdílení",
-    "Invalid path selected" : "Je vybrána neplatná cesta",
+    "Invalid path selected" : "Je vybrán neplatný popis umístění",
     "Open in sidebar view" : "Otevřít v zobrazení v postranním panelu",
     "Open in bigger view" : "Otevřít ve větším zobrazení",
     "Attachments" : "Přílohy",
@@ -197,6 +200,7 @@ OC.L10N.register(
     "Created" : "Vytvořeno",
     "The title cannot be empty." : "Nadpis je třeba vyplnit.",
     "No comments yet. Begin the discussion!" : "Zatím bez komentářů. Zahajte diskuzi!",
+    "Failed to load comments" : "Načtení komentářů se nezdařilo",
     "Assign a tag to this card…" : "Přiřadit této kartě štítek…",
     "Assign to users" : "Přiřadit k uživatelům",
     "Assign to users/groups/circles" : "Přiřadit uživatelům/skupinám/okruhům",
@@ -209,6 +213,7 @@ OC.L10N.register(
     "The comment cannot be empty." : "Komentář je třeba vyplnit.",
     "The comment cannot be longer than 1000 characters." : "Délka komentáře může být nejvýše 1 000 znaků.",
     "In reply to" : "V odpověď na",
+    "Cancel reply" : "Zrušit odpověď",
     "Reply" : "Odpovědět",
     "Update" : "Aktualizovat",
     "Description" : "Popis",
@@ -221,7 +226,7 @@ OC.L10N.register(
     "Write a description …" : "Zadejte popis…",
     "Choose attachment" : "Zvolte přílohu",
     "(group)" : "(skupina)",
-    "(circle)" : "(okruh)",
+    "{count} comments, {unread} unread" : "{count} komentářů, {unread} nepřečtených",
     "Assign to me" : "Přiřadit mě",
     "Unassign myself" : "Zrušit přiřazení sobě",
     "Move card" : "Přesunout kartu",
@@ -261,6 +266,8 @@ OC.L10N.register(
     "Tomorrow" : "Zítra",
     "This week" : "Tento týden",
     "No due" : "Žádný termín",
+    "Search for {searchQuery} in all boards" : "Hledat {searchQuery} na všech tabulích",
+    "No results found" : "Nenalezeny žádné výsledky",
     "No upcoming cards" : "Žádné nadcházející karty",
     "upcoming cards" : "nadcházející karty",
     "Link to a board" : "Propojit s tabulí",
