@@ -5,7 +5,6 @@ OC.L10N.register(
     "Personal" : "Personal",
     "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alacanzado su fecha de entrega",
     "The board \"%s\" has been shared with you by %s." : "El tablero \"%s\" ha sido compartido contigo por %s.",
-    "{user} has shared the board %s with you." : "{user} ha compartido el tablero %s contigo. ",
     "Finished" : "Terminado",
     "To review" : "Para revisar",
     "Action needed" : "Acción requerida",
@@ -29,9 +28,7 @@ OC.L10N.register(
     "Delete" : "Borrar",
     "Add card" : "Agregar tarjeta",
     "Edit" : "Editar",
-    "Title" : "Título",
     "Members" : "Miembros",
-    "Upload attachment" : "Cargar adjunto",
     "Comments" : "Comentarios",
     "Modified" : "Modificado",
     "Created" : "Creado",
