@@ -70,12 +70,9 @@ OC.L10N.register(
     "Upcoming cards" : "כרטיסים עתידיים",
     "Personal" : "אישי",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "הכרטיס \"%s\" שב־„%s” הוקצה אליך על ידי %s.",
-    "{user} has assigned the card \"%s\" on \"%s\" to you." : "הכרטיס „%s” שב„%s” הוקצה לך על ידי {user}.",
     "The card \"%s\" on \"%s\" has reached its due date." : "הכרטיס „%s” שתחת „%s” הגיע למועד התפוגה שלו.",
     "%s has mentioned you in a comment on \"%s\"." : "אוזכרת על ידי %s בתגובה על „%s”.",
-    "{user} has mentioned you in a comment on \"%s\"." : "אוזכרת על ידי {user} בתגובה על „%s”.",
     "The board \"%s\" has been shared with you by %s." : "הלוח „%s” שותף אתך על ידי %s.",
-    "{user} has shared the board %s with you." : "הלוח %s שותף אתך על ידי {user}",
     "No data was provided to create an attachment." : "לא סופקו נתונים ליצירת קובץ מצורף",
     "Finished" : "הסתיים",
     "To review" : "לסקירה",
@@ -214,7 +211,6 @@ OC.L10N.register(
     "Write a description …" : "כתוב תיאור ...",
     "Choose attachment" : "בחירת קובץ מצורף",
     "(group)" : "(קבוצה)",
-    "(circle)" : "(מעגל)",
     "Assign to me" : "הקצאה אלי",
     "Unassign myself" : "לבטל את הקצאת עצמי",
     "Move card" : "העברת כרטיס",
