@@ -63,18 +63,18 @@ OC.L10N.register(
     "{user} has restored the attachment {attachment} to card {card}" : "{user}が添付ファイル{attachment}をカード{card}に復元しました",
     "You have commented on card {card}" : "カード{card}にコメントしました",
     "{user} has commented on card {card}" : "{user}がカード{card}にコメントしました",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "デッキアプリ内の<strong>カードの説明</strong>が変更されました",
+    "A <strong>card description</strong> inside the Deck app has been changed" : "デッキアプリ内の<strong>カードの説明</strong>が変更されたとき",
     "Deck" : "デッキ",
-    "Changes in the <strong>Deck app</strong>" : "<strong>デッキアプリ</strong>の変更点",
+    "Changes in the <strong>Deck app</strong>" : "<strong>デッキアプリ</strong>に変更があったとき",
     "A <strong>comment</strong> was created on a card" : "カードに<strong>コメント</strong>が作成されたとき",
+    "Upcoming cards" : "今後のカード",
     "Personal" : "個人",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "カード \"%s\"(\"%s\"に所属)が%sによってあなたに割り当てられました。",
-    "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user}はあなたに カード \"%s\"(\"%s\"に所属)を割り当てました。",
     "The card \"%s\" on \"%s\" has reached its due date." : "カード \"%s\"(\"%s\"に所属)は期日に達しました。",
     "%s has mentioned you in a comment on \"%s\"." : "%sさんは \"%s\"へのコメントであなたについて言及しました。",
-    "{user} has mentioned you in a comment on \"%s\"." : "{user} は \"%s\"へのコメントであなたについて言及しました。",
     "The board \"%s\" has been shared with you by %s." : "\"%s\" ボードは、%s からあなたに共有されています。",
-    "{user} has shared the board %s with you." : "{user}があなたとボード%sを共有しました。",
+    "Card comments" : "カードコメント",
+    "%s on %s" : "%s が %s で",
     "No data was provided to create an attachment." : "添付ファイルを作成するためのデータは提供されていません。",
     "Finished" : "完了",
     "To review" : "レビューする",
@@ -96,6 +96,9 @@ OC.L10N.register(
     "Could not write file to disk" : "ディスクにファイルを書き込めませんでした",
     "A PHP extension stopped the file upload" : "PHP拡張でファイルのアップロードが停止されています",
     "No file uploaded or file size exceeds maximum of %s" : "ファイルがアップロードされていないか、ファイルサイズが最大 %s を超えています",
+    "Card not found" : "カードが見つかりません",
+    "Path is already shared with this card" : "パスは既にこのカードで共有されています",
+    "Invalid date, date format must be YYYY-MM-DD" : "日付が無効です。日付形式はYYYY-MM-DDである必要があります",
     "Personal planning and team project organization" : "個人的な計画とチームのプロジェクト編成",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "DeckはNextcloudと統合した、チームの個人計画とプロジェクトの組織化を目的としたカンバンスタイルの組織ツールです。\n\n\n- 📥 タスクをカードに追加して整理する\n- 📄 マークダウンで追加のメモを書き留めます\n- 🔖 より良い組織のためにラベルを割り当てる\n- 👥 あなたのチーム、友人、家族と共有する\n- 📎 ファイルを添付してマークダウンの説明に埋め込む\n- 💬 コメントを使ってあなたのチームと話し合う\n- ⚡ アクティビティの流れの変化を追跡する\n- 🚀 プロジェクトを整理する",
     "Card details" : "カード詳細",
@@ -103,9 +106,14 @@ OC.L10N.register(
     "Select the board to link to a project" : "プロジェクトにリンクするボードを選択",
     "Search by board title" : "ボードのタイトルで検索",
     "Select board" : "ボードを選択",
+    "Create a new card" : "新しいカードを作成する",
     "Select a board" : "ボードを選択",
     "Select a list" : "リストを選択",
+    "Card title" : "カードのタイトル",
     "Cancel" : "キャンセル",
+    "Open card" : "カードを開く",
+    "Close" : "閉じる",
+    "Create card" : "カードを作成",
     "Select a card" : "カードを選択",
     "Select the card to link to a project" : "プロジェクトにリンクするカードを選択",
     "Link to card" : "カードへリンク",
@@ -135,6 +143,8 @@ OC.L10N.register(
     "Toggle compact mode" : "コンパクトモードの切り替え",
     "Details" : "詳細",
     "Loading board" : "ボードを読み込み中",
+    "No lists available" : "利用可能なリストはありません",
+    "Create a new list to add cards to this board" : "このボードにカードを追加するための新しいリストを作成します",
     "Board not found" : "ボードが見つかりません",
     "Sharing" : "共有中",
     "Tags" : "タグ",
@@ -144,6 +154,8 @@ OC.L10N.register(
     "Undo" : "元に戻す",
     "Deleted cards" : "削除済みのカード",
     "Share board with a user, group or circle …" : "ボードをユーザー、グループまたはサークルと共有…",
+    "Searching for users, groups and circles …" : "ユーザー、グループ、サークルを検索しています…",
+    "No participants found" : "参加者が見つかりません",
     "Board owner" : "ボード所有者",
     "(Group)" : "(グループ)",
     "(Circle)" : "(サークル)",
@@ -151,26 +163,41 @@ OC.L10N.register(
     "Can share" : "共有可能",
     "Can manage" : "管理可能",
     "Delete" : "削除",
+    "Failed to create share with {displayName}" : "{displayName}との共有の作成に失敗しました",
     "Add a new list" : "新しいリストを追加",
+    "Archive all cards" : "すべてのカードをアーカイブする",
     "Delete list" : "リストを削除",
     "Add card" : "カードを追加",
+    "Archive all cards in this list" : "このリストのすべてのカードをアーカイブする",
     "Add a new card" : "新しいカードを追加",
+    "Card name" : "カード名",
+    "List deleted" : "リストが削除されました",
     "Edit" : "編集",
     "Add a new tag" : "新しいタグを追加",
     "title and color value must be provided" : "タイトルと色の値を指定する必要があります",
+    "Board name" : "ボード名",
     "Members" : "メンバー",
+    "Upload new files" : "新しいファイルをアップロード",
+    "Share from Files" : "ファイルから共有",
     "Add this attachment" : "この添付ファイルを追加",
+    "Show in Files" : "ファイルに表示",
+    "Unshare file" : "ファイルの共有を解除する",
     "Delete Attachment" : "添付ファイルを削除",
     "Restore Attachment" : "添付ファイルを復元",
+    "File to share" : "共有するファイル",
+    "Invalid path selected" : "無効なパスが選択されました",
+    "Open in sidebar view" : "サイドバービューで開く",
+    "Open in bigger view" : "拡大表示で開く",
     "Attachments" : "添付ファイル",
     "Comments" : "コメント",
     "Modified" : "更新日時",
     "Created" : "作成時刻",
+    "The title cannot be empty." : "タイトルを空にすることはできません。",
     "No comments yet. Begin the discussion!" : "まだコメントはありません。議論を始めましょう！",
     "Assign a tag to this card…" : "タグこのをカードに割り当てる…",
     "Assign to users" : "ユーザーに割り当てる",
     "Assign to users/groups/circles" : "ユーザー/グループ/サークルに割り当てる",
-    "Assign a user to this card…" : "このカードにユーザーに割り当てる…",
+    "Assign a user to this card…" : "このカードをユーザーに割り当てる…",
     "Due date" : "期限",
     "Set a due date" : "期限を設定",
     "Remove due date" : "期限を削除",
@@ -188,9 +215,9 @@ OC.L10N.register(
     "Edit description" : "説明を編集",
     "View description" : "説明を表示",
     "Add Attachment" : "添付ファイルを追加",
+    "Write a description …" : "説明を書く…",
     "Choose attachment" : "添付ファイルを選択",
     "(group)" : "(グループ)",
-    "(circle)" : "(サークル)",
     "Assign to me" : "自分に割り当てる",
     "Unassign myself" : "自分への割り当てを解除",
     "Move card" : "カードの移動",
@@ -198,24 +225,52 @@ OC.L10N.register(
     "Archive card" : "カードをアーカイブ",
     "Delete card" : "カードを削除する",
     "Move card to another board" : "カードを他のボードに移動",
+    "Card deleted" : "カードが削除されました",
     "seconds ago" : "数秒前",
     "All boards" : "すべてのボード",
     "Archived boards" : "アーカイブ済みのボード",
     "Shared with you" : "あなたと共有済み",
+    "Use bigger card view" : "大きなカードビューを使用する",
+    "Show boards in calendar/tasks" : "カレンダー/タスクでボードを表示する",
     "Limit deck usage of groups" : "デッキの使用をグループに制限",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "デッキ作成制限は、設定したグループに非所属のユーザーがボードを作成できないようにします。非所属ユーザーは共有されているボードでのみ作業できます。",
     "Board details" : "ボードの詳細",
     "Edit board" : "ボードを編集",
+    "Clone board" : "ボードを複製",
+    "Unarchive board" : "ボードのアーカイブを解除",
+    "Archive board" : "ボードをアーカイブ",
+    "Turn on due date reminders" : "期日のリマインダーをオンにする",
+    "Turn off due date reminders" : "期日のリマインダーをオフにする",
+    "Due date reminders" : "期日のリマインダー",
+    "All cards" : "すべてのカード",
+    "Assigned cards" : "割り当てられたカード",
+    "No notifications" : "非通知",
+    "Delete board" : "ボードを削除",
     "Board {0} deleted" : "ボード {0} 削除済み",
+    "Only assigned cards" : "割り当てられたカードのみ",
+    "No reminder" : "リマインダーなし",
     "An error occurred" : "エラーが発生しました",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "このボード{title}を削除してもよろしいですか？この操作はこのボードのデータすべてを削除します。",
     "Delete the board?" : "ボードを削除しますか？",
+    "Loading filtered view" : "フィルタされたビューを読み込み中",
     "Today" : "今日",
     "Tomorrow" : "明日",
     "This week" : "今週",
+    "No due" : "日付なし",
+    "Search for {searchQuery} in all boards" : "すべてのボードで{searchQuery}を検索します",
+    "No results found" : "結果が見つかりません",
+    "No upcoming cards" : "今後のカードはありません",
+    "upcoming cards" : "今後のカード",
     "Link to a board" : "ボードへのリンク",
     "Link to a card" : "カードへリンク",
+    "Create a card" : "カードを作成",
+    "Message from {author} in {conversationName}" : "{conversationName} で {author} からのメッセージ",
     "Something went wrong" : "何かがおかしいです",
-    "Maximum file size of {size} exceeded" : "最大ファイルサイズ（{size}）を超えています"
+    "Failed to upload {name}" : "{name}のアップロードに失敗しました",
+    "Maximum file size of {size} exceeded" : "最大ファイルサイズ（{size}）を超えています",
+    "Error creating the share" : "共有の作成中にエラーが発生しました",
+    "Share with a Deck card" : "デッキのカードで共有する",
+    "Share {file} with a Deck card" : "{file}をデッキのカードで共有する",
+    "Share" : "共有"
 },
 "nplurals=1; plural=0;");
