@@ -68,12 +68,9 @@ OC.L10N.register(
     "Upcoming cards" : "Artėjančios kortelės",
     "Personal" : "Asmeniniai",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kortelę \"%s\" ties \"%s\" priskyrė jums %s.",
-    "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} priskyrė jums kortelę \"%s\" ties \"%s\".",
     "The card \"%s\" on \"%s\" has reached its due date." : "Kortelė „%s“, esanti lentoje „%s“, pasiekė savo galutinį terminą.",
     "%s has mentioned you in a comment on \"%s\"." : "%s paminėjo jus komentare ties \"%s\".",
-    "{user} has mentioned you in a comment on \"%s\"." : "{user} paminėjo jus komentare ties \"%s\".",
     "The board \"%s\" has been shared with you by %s." : "Lentą \"%s\" su jumis bendrina %s.",
-    "{user} has shared the board %s with you." : "{user} pradėjo su jumis bendrinti lentą %s.",
     "No data was provided to create an attachment." : "Priedo sukūrimui nebuvo pateikta jokių duomenų.",
     "Finished" : "Baigta",
     "To review" : "Reikia peržiūrėti",
@@ -200,7 +197,6 @@ OC.L10N.register(
     "Add Attachment" : "Pridėti priedą",
     "Choose attachment" : "Pasirinkite priedą",
     "(group)" : "(grupė)",
-    "(circle)" : "(ratas)",
     "Assign to me" : "Priskirti sau",
     "Move card" : "Perkelti kortelę",
     "Unarchive card" : "Išarchyvuoti kortelę",
