@@ -6,12 +6,17 @@ OC.L10N.register(
     "Cancel" : "Anullar",
     "Details" : "Detalhs",
     "Sharing" : "Partiment",
+    "Tags" : "Etiquetas",
+    "Deleted items" : "Elements suprimits",
+    "Deleted lists" : "Listas suprimidas",
+    "(Group)" : "(Grop)",
     "Can edit" : "Can edit",
     "Can share" : "Can share",
     "Delete" : "Suprimir",
     "Edit" : "Modificar",
     "Upload new files" : "Enviar fichièrs novèls",
     "Save" : "Salvar",
+    "Cancel reply" : "Anullar la responsa",
     "Reply" : "Respondre",
     "Update" : "Metre a jorn",
     "Description" : "Descripcion",
