@@ -70,12 +70,9 @@ OC.L10N.register(
     "Upcoming cards" : "Nadchádzajúce karty",
     "Personal" : "Osobné",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Používateľ %s vám priradil kartu „%s“ na „%s“.",
-    "{user} has assigned the card \"%s\" on \"%s\" to you." : "Používateľ {user} vám priradil kartu „%s“ na „%s“.",
     "The card \"%s\" on \"%s\" has reached its due date." : "Karta \"%s\" na nástenke \"%s\" dosiahla termín dokončenia.",
     "%s has mentioned you in a comment on \"%s\"." : "Používateľ %s vás zmienil v komentári ku „%s“.",
-    "{user} has mentioned you in a comment on \"%s\"." : "Používateľ {user} vás zmienil v komentári v „%s“.",
     "The board \"%s\" has been shared with you by %s." : "Používateľ %s vám sprístupnil nástenku \"%s\".",
-    "{user} has shared the board %s with you." : "Používateľ {user} vám sprístupnil nástenku %s.",
     "No data was provided to create an attachment." : "Neboli poskytnuté dáta pre vytvorenie prílohy.",
     "Finished" : "Ukončené",
     "To review" : "Na posúdenie",
@@ -205,7 +202,6 @@ OC.L10N.register(
     "Write a description …" : "Napíšte popis...",
     "Choose attachment" : "Vybrať prílohu",
     "(group)" : "(skupina)",
-    "(circle)" : "(okruh)",
     "Assign to me" : "Priradiť mne",
     "Unassign myself" : "Zrušiť priradenie mne",
     "Move card" : "Presunúť kartu",
