@@ -70,12 +70,15 @@ OC.L10N.register(
     "Upcoming cards" : "Prihajajoče naloge",
     "Personal" : "Osebno",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Nalogo »%s« na »%s« vam dodeli %s.",
-    "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} vam dodeli nalogo »%s« na »%s«.",
+    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} vam dodeli nalogo »{deck-card}« na »{deck-board}«.",
     "The card \"%s\" on \"%s\" has reached its due date." : "Naloga »%s« na »%s« je dosegla datum preteka.",
+    "The card {deck-card} on {deck-board} has reached its due date." : "Naloga »{deck-card} « na »{deck-board}« je dosegla datum preteka.",
     "%s has mentioned you in a comment on \"%s\"." : "%s vas omeni v opombi na »%s«.",
-    "{user} has mentioned you in a comment on \"%s\"." : "{user} vas omeni v opombi na »%s«.",
+    "{user} has mentioned you in a comment on {deck-card}." : "{user} vas omeni v opombi na »{deck-card}«.",
     "The board \"%s\" has been shared with you by %s." : "Zbirko »%s« vam dodeli %s.",
-    "{user} has shared the board %s with you." : "{user} vam omogoča souporabo zbirke %s.",
+    "{user} has shared {deck-board} with you." : "{user} vam omogoča souporabo zbirke {deck-board}.",
+    "Card comments" : "Opombe k nalogi",
+    "%s on %s" : "%s v nalogi %s",
     "No data was provided to create an attachment." : "Ni podanih podatkov za ustvarjanje priloge.",
     "Finished" : "Končano",
     "To review" : "Za pregled",
@@ -112,8 +115,8 @@ OC.L10N.register(
     "Select a list" : "Izbor seznama",
     "Card title" : "Naslov naloge",
     "Cancel" : "Prekliči",
-    "Creating the new card…" : "Poteka ustvarjanje nove naloge ...",
-    "\"{card}\" was added to \"{board}\"" : "Naloga »{card}« je dodana v zbirko »{board}«.",
+    "Creating the new card …" : "Poteka ustvarjanje nove naloge ...",
+    "Card \"{card}\" was added to \"{board}\"" : "Naloga »{card}« je dodana v zbirko »{board}«.",
     "Open card" : "Odpri nalogo",
     "Close" : "Zapri",
     "Create card" : "Ustvari nalogo",
@@ -197,6 +200,7 @@ OC.L10N.register(
     "Created" : "Ustvarjeno",
     "The title cannot be empty." : "Polje naslova ne sme biti prazno.",
     "No comments yet. Begin the discussion!" : "Ni še odzivov, bodite prvi!",
+    "Failed to load comments" : "Nalaganje opomb je spodletelo.",
     "Assign a tag to this card…" : "Dodeli oznako nalogi ...",
     "Assign to users" : "Dodeli uporabnikom",
     "Assign to users/groups/circles" : "Dodeli uporabnikom/skupinam/krogom",
@@ -209,6 +213,7 @@ OC.L10N.register(
     "The comment cannot be empty." : "Polje opombe ne sme biti prazno.",
     "The comment cannot be longer than 1000 characters." : "Opomba ne sme biti daljša od 1000 znakov.",
     "In reply to" : "V odgovor",
+    "Cancel reply" : "Prekliči odgovor",
     "Reply" : "Odgovori",
     "Update" : "Posodobi",
     "Description" : "Opis",
@@ -221,7 +226,7 @@ OC.L10N.register(
     "Write a description …" : "Vpišite opis ...",
     "Choose attachment" : "Izbor priloge",
     "(group)" : "(skupina)",
-    "(circle)" : "(krog)",
+    "{count} comments, {unread} unread" : "{count} sporočil, {unread} neprebranih",
     "Assign to me" : "Nalogo dodeli meni",
     "Unassign myself" : "Odstrani me z naloge",
     "Move card" : "Premakni nalogo",
@@ -261,11 +266,14 @@ OC.L10N.register(
     "Tomorrow" : "Jutri",
     "This week" : "Ta teden",
     "No due" : "Ni datuma preteka",
+    "Search for {searchQuery} in all boards" : "Poišči {searchQuery} med vsemi zbirkami nalog.",
+    "No results found" : "Ni najdenih zadetkov",
     "No upcoming cards" : "Ni prihajajočih nalog",
     "upcoming cards" : "prihajajoče naloge",
     "Link to a board" : "Povezava do zbirke",
     "Link to a card" : "Povezava do naloge",
     "Create a card" : "Ustvari nalogo",
+    "Message from {author} in {conversationName}" : "{author} objavi sporočilo v pogovoru {conversationName}",
     "Something went wrong" : "Prišlo je do napake ...",
     "Failed to upload {name}" : "Pošiljanje {name} je spodletelo",
     "Maximum file size of {size} exceeded" : "Omejitev velikosti datoteke {size} je prekoračena.",
