@@ -63,19 +63,22 @@ OC.L10N.register(
     "{user} has restored the attachment {attachment} to card {card}" : "{user} har återställt bilagan {attachment} till kortet {card}",
     "You have commented on card {card}" : "Du har kommenterat på kortet {card}",
     "{user} has commented on card {card}" : "{user} har kommenterat på kortet {card}",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "En <strong>kortbeskrivning</strong> i Deck-appen har ändrats",
-    "Deck" : "Deck",
-    "Changes in the <strong>Deck app</strong>" : "Ändringar i <strong>Deck-appen</strong>",
+    "A <strong>card description</strong> inside the Deck app has been changed" : "En <strong>kortbeskrivning</strong> i Kortlek-appen har ändrats",
+    "Deck" : "Kortlek",
+    "Changes in the <strong>Deck app</strong>" : "Ändringar i <strong>Kortlek-appen</strong>",
     "A <strong>comment</strong> was created on a card" : "En <strong>kommentar</strong> skapades på ett kort",
     "Upcoming cards" : "Kommande kort",
     "Personal" : "Personlig",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kortet \"%s\" på \"%s\" har tilldelats dig av %s.",
-    "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} har tilldelat kortet \"%s\" på \"%s\" till dig.",
-    "The card \"%s\" on \"%s\" has reached its due date." : "Kortet \"%s\" på \"%s\" har nått sitt utgångsdatum.",
+    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} har tilldelat kortet {deck-card} från {deck-board} till dig.",
+    "The card \"%s\" on \"%s\" has reached its due date." : "Kortet \"%s\" på \"%s\" har nått sitt slutdatum.",
+    "The card {deck-card} on {deck-board} has reached its due date." : "Kortet {deck-card} från {deck-board} har nått sitt slutdatum.",
     "%s has mentioned you in a comment on \"%s\"." : "%s har nämnt dig i en kommentar på \"%s\".",
-    "{user} has mentioned you in a comment on \"%s\"." : "{user} har nämnt dig i en kommentar på \"%s\".",
+    "{user} has mentioned you in a comment on {deck-card}." : "{user} har nämnt dig i en kommentar i {deck-card}.",
     "The board \"%s\" has been shared with you by %s." : "Tavlan \"%s\" har delats med dig av %s.",
-    "{user} has shared the board %s with you." : "{user} har delat tavlan %s med dig.",
+    "{user} has shared {deck-board} with you." : "{user} har delat {deck-board} med dig.",
+    "Card comments" : "Kort kommentarer",
+    "%s on %s" : "%s på %s",
     "No data was provided to create an attachment." : "Inga data lämnades för att skapa en bilaga.",
     "Finished" : "Slutförd",
     "To review" : "Att granska",
@@ -97,16 +100,26 @@ OC.L10N.register(
     "Could not write file to disk" : "Kunde inte skriva fil till disk",
     "A PHP extension stopped the file upload" : "Ett PHP-tillägg stoppade filuppladdningen",
     "No file uploaded or file size exceeds maximum of %s" : "Ingen fil uppladdad eller filstorleken överstiger max %s",
+    "Card not found" : "Kortet hittades inte",
+    "Path is already shared with this card" : "Sökvägen är redan delad med detta kort",
+    "Invalid date, date format must be YYYY-MM-DD" : "Ogiltigt datum, måste anges: ÅÅÅÅ-MM-DD",
     "Personal planning and team project organization" : "Personlig planering och projekthantering för teams",
-    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Korthögar är en kanban-liknande projekt- och organiseringsapp för arbetsgrupper i Nextcloud.\n\n\n- 📥 Lägg till uppgifter på kort och ordna dem\n- 📄 Skriv anteckningar i markdown\n- 🔖 Tilldela etiketter för organisering\n- 👥 Dela med arbetsgruppen, vänner eller familj\n- 📎 Bifoga filer och bädda in dem i markdown-anteckningarna\n- 💬 Diskutera i arbetsgruppen genom kommentarer\n- ⚡ Håll koll på ändringar i aktivitetsflödet\n- 🚀 Börja organisera din arbetsgrupp nu!",
+    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Kortlek är en kanban-liknande projekt- och organiseringsapp för arbetsgrupper i Nextcloud.\n\n\n- 📥 Lägg till uppgifter på kort och ordna dem\n- 📄 Skriv anteckningar i markdown\n- 🔖 Tilldela etiketter för organisering\n- 👥 Dela med arbetsgruppen, vänner eller familj\n- 📎 Bifoga filer och bädda in dem i markdown-anteckningarna\n- 💬 Diskutera i arbetsgruppen genom kommentarer\n- ⚡ Håll koll på ändringar i aktivitetsflödet\n- 🚀 Börja organisera din arbetsgrupp nu!",
     "Card details" : "Kortdetaljer",
     "Add board" : "Lägg till tavla",
     "Select the board to link to a project" : "Välj tavla att länka till ett projekt",
     "Search by board title" : "Sök efter namn på tavla",
     "Select board" : "Välj tavla",
+    "Create a new card" : "Skapa ett nytt kort",
     "Select a board" : "Välj en tavla",
     "Select a list" : "Välj en lista",
+    "Card title" : "Kort-titel",
     "Cancel" : "Avbryt",
+    "Creating the new card …" : "Skapar det nya kortet ...",
+    "Card \"{card}\" was added to \"{board}\"" : "kortet \"{card}\" lades till i \"{board}\"",
+    "Open card" : "Öppna kort",
+    "Close" : "Stäng",
+    "Create card" : "Skapa kort",
     "Select a card" : "Välj ett kort",
     "Select the card to link to a project" : "Välj kort att länka till ett projekt",
     "Link to card" : "Länka till kort",
@@ -170,9 +183,15 @@ OC.L10N.register(
     "title and color value must be provided" : "titel och färg måste anges",
     "Board name" : "Tavlans namn",
     "Members" : "Medlemmar",
+    "Upload new files" : "Ladda upp nya filer",
+    "Share from Files" : "Dela från Filer",
     "Add this attachment" : "Lägg till denna bilaga",
+    "Show in Files" : "Visa i Filer",
+    "Unshare file" : "Sluta dela fil",
     "Delete Attachment" : "Ta bort bilaga",
     "Restore Attachment" : "Återställ bilaga",
+    "File to share" : "Fil att dela",
+    "Invalid path selected" : "Ogiltig sökväg vald",
     "Open in sidebar view" : "Öppna i sidofältet",
     "Open in bigger view" : "Öppna i större vy",
     "Attachments" : "Bilagor",
@@ -181,6 +200,7 @@ OC.L10N.register(
     "Created" : "Skapat",
     "The title cannot be empty." : "Titeln får inte lämnas tom.",
     "No comments yet. Begin the discussion!" : "Inga kommentarer än. Börja diskussionen!",
+    "Failed to load comments" : "Kunde inte ladda kommentarerna.",
     "Assign a tag to this card…" : "Tilldela en tagg till det här kortet ...",
     "Assign to users" : "Tilldela till användare",
     "Assign to users/groups/circles" : "Tilldela till användare/grupper/cirklar",
@@ -193,6 +213,7 @@ OC.L10N.register(
     "The comment cannot be empty." : "Kommentaren kan inte vara tom.",
     "The comment cannot be longer than 1000 characters." : "Kommentaren kan inte vara längre än 1000 tecken.",
     "In reply to" : "Som svar på",
+    "Cancel reply" : "Avbryt svar",
     "Reply" : "Svara",
     "Update" : "Uppdatera",
     "Description" : "Beskrivning",
@@ -205,7 +226,7 @@ OC.L10N.register(
     "Write a description …" : "Ange en beskrivning ...",
     "Choose attachment" : "Välj bilaga",
     "(group)" : " (grupp)",
-    "(circle)" : "(cirkel)",
+    "{count} comments, {unread} unread" : "{count} kommentarer, {unread} olästa",
     "Assign to me" : "Tilldela till mig",
     "Unassign myself" : "Ta bort från mig själv",
     "Move card" : "Flytta kort",
@@ -218,9 +239,10 @@ OC.L10N.register(
     "All boards" : "Alla tavlor",
     "Archived boards" : "Arkiverade tavlor",
     "Shared with you" : "Delad med dig",
+    "Use bigger card view" : "Visa större kort",
     "Show boards in calendar/tasks" : "Visa tavlor i kalender / uppgifter",
     "Limit deck usage of groups" : "Begränsa användningen av grupper",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Begränsa Deck blockerar användare som inte ingår i dessa grupper från att skapa egna tavlor. Användare kan fortfarande arbeta med tavlor som har delats med dem.",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Begränsning av Kortlek blockerar användare som inte ingår i dessa grupper från att skapa egna tavlor. Användare kan dock fortfarande integrera med tavlor som har delats med dem.",
     "Board details" : "Taveldetaljer",
     "Edit board" : "Ändra tavla",
     "Clone board" : "Kopiera tavla",
@@ -244,11 +266,20 @@ OC.L10N.register(
     "Tomorrow" : "Imorgon",
     "This week" : "Denna vecka",
     "No due" : "Inget slut",
+    "Search for {searchQuery} in all boards" : "Sök efter {searchQuery} i alla tavlor",
+    "No results found" : "Inga resultat funna",
     "No upcoming cards" : "Inga kommande kort",
     "upcoming cards" : "kommande kort",
     "Link to a board" : "Länka till en tavla",
     "Link to a card" : "Länka till ett kort",
+    "Create a card" : "Skapa ett kort",
+    "Message from {author} in {conversationName}" : "Meddelande från {author} i {conversationName}",
     "Something went wrong" : "Något gick fel",
-    "Maximum file size of {size} exceeded" : "Maximal filstorlek på {size} överskriden"
+    "Failed to upload {name}" : "Kunde inte ladda upp {name}",
+    "Maximum file size of {size} exceeded" : "Maximal filstorlek på {size} överskriden",
+    "Error creating the share" : "Kunde inte skapa delning",
+    "Share with a Deck card" : "Dela med ett Kortlek-kort",
+    "Share {file} with a Deck card" : "Dela {file} med ett Kortlek-kort",
+    "Share" : "Dela"
 },
 "nplurals=2; plural=(n != 1);");
