@@ -20,10 +20,8 @@ OC.L10N.register(
     "Deck" : "Kế hoạch",
     "Personal" : "Cá nhân",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Tác vụ \"%s\" trong \"%s\" đã được phân công cho bạn bởi  %s.",
-    "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} đã phân công tác vụ \"%s\" trong \"%s\" cho bạn.",
     "The card \"%s\" on \"%s\" has reached its due date." : "Tác vụ \"%s\" trong \"%s\" đã đến ngày hạn chót.",
     "The board \"%s\" has been shared with you by %s." : "Dự án \"%s\" đã được chia sẽ với bạn bởi %s .",
-    "{user} has shared the board %s with you." : "{user} đã chia sẽ dự án %s với bạn.",
     "No data was provided to create an attachment." : "Không có dữ liệu từ nhà cung cấp để tạo một đính kèm",
     "Finished" : "Đã hoàn tất",
     "To review" : "Xem thử",
