@@ -70,12 +70,15 @@ OC.L10N.register(
     "Upcoming cards" : "即将到来的卡片",
     "Personal" : "个人",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "卡片  \"%s\" （在 \"%s\" 中）已由%s指派给您。",
-    "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} 已将卡片 \"%s\" （在 \"%s\" 中）指派给您。",
+    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} 已将卡片 {deck-card}， 其位于 {deck-board} ，分配给了你",
     "The card \"%s\" on \"%s\" has reached its due date." : "卡片 \"%s\" （在 \"%s\" 中）已到期.",
+    "The card {deck-card} on {deck-board} has reached its due date." : "卡片 {deck-card}， 其位于 {deck-board} ，已到期",
     "%s has mentioned you in a comment on \"%s\"." : "%s 在 “%s” 的评论中提到了您。",
-    "{user} has mentioned you in a comment on \"%s\"." : "{user} 在 “%s” 的评论中提到了您。",
+    "{user} has mentioned you in a comment on {deck-card}." : "{user} 在 {deck-card} 的一条评论中提到了你",
     "The board \"%s\" has been shared with you by %s." : "面板 \"%s\" 已由 %s 共享给您。",
-    "{user} has shared the board %s with you." : "{user} 共享面板 %s 给您。",
+    "{user} has shared {deck-board} with you." : "{user} 与你分享了 {deck-board}",
+    "Card comments" : "卡片评论",
+    "%s on %s" : "%s 于 %s",
     "No data was provided to create an attachment." : "未能提供数据以创建附件",
     "Finished" : "已完成",
     "To review" : "待复核",
@@ -112,8 +115,8 @@ OC.L10N.register(
     "Select a list" : "选择一个列表",
     "Card title" : "卡片标题",
     "Cancel" : "取消",
-    "Creating the new card…" : "正在创建新卡片…",
-    "\"{card}\" was added to \"{board}\"" : "卡片 \"{card}\" 被添加到看板 \"{board}\"",
+    "Creating the new card …" : "正在创建新卡片… ",
+    "Card \"{card}\" was added to \"{board}\"" : "卡片 \"{card}\" 被添加至看板 \"{board}\"",
     "Open card" : "打开卡片",
     "Close" : "关闭",
     "Create card" : "创建卡片",
@@ -197,6 +200,7 @@ OC.L10N.register(
     "Created" : "已创建",
     "The title cannot be empty." : "标题不能为空",
     "No comments yet. Begin the discussion!" : "还没有评论。 开始讨论吧！",
+    "Failed to load comments" : "加载评论失败",
     "Assign a tag to this card…" : "为该卡片分配标签…",
     "Assign to users" : "指派给用户",
     "Assign to users/groups/circles" : "指派给用户/群组/圈子",
@@ -209,6 +213,7 @@ OC.L10N.register(
     "The comment cannot be empty." : "注释不能为空。",
     "The comment cannot be longer than 1000 characters." : "注释不能超过 1000 个字符。",
     "In reply to" : "回复",
+    "Cancel reply" : "取消回复",
     "Reply" : "回复",
     "Update" : "更新",
     "Description" : "描述",
@@ -221,7 +226,7 @@ OC.L10N.register(
     "Write a description …" : "写一段描述",
     "Choose attachment" : "选择附件",
     "(group)" : "（组）",
-    "(circle)" : "（圈子）",
+    "{count} comments, {unread} unread" : "{count} 条评论，{unread} 未读",
     "Assign to me" : "指派给我",
     "Unassign myself" : "不再指派给我",
     "Move card" : "移动卡片",
@@ -261,6 +266,8 @@ OC.L10N.register(
     "Tomorrow" : "明天",
     "This week" : "本周",
     "No due" : "没有到期的",
+    "Search for {searchQuery} in all boards" : "在所有看板中搜索 {searchQuery}",
+    "No results found" : "未找到结果",
     "No upcoming cards" : "没有即将到来的卡片",
     "upcoming cards" : "即将到来的卡片",
     "Link to a board" : "链接到一个面板",
