@@ -70,12 +70,15 @@ OC.L10N.register(
     "Upcoming cards" : "快將到期的卡片",
     "Personal" : "個人",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "%s 已將 “%s” 中的卡片 “%s” 指派給您。",
-    "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} 已將 “%s” 中的卡片 “%s” 指派給您。",
+    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} 已將 {deck-board} 中的卡片 {deck-card} 指派給您。",
     "The card \"%s\" on \"%s\" has reached its due date." : "\"%s\"中的卡片 \"%s\" 已到期。",
+    "The card {deck-card} on {deck-board} has reached its due date." : "deck-board} 中的卡片{deck-card} 已到期。",
     "%s has mentioned you in a comment on \"%s\"." : "%s 在 “%s” 的意見中提到了您。",
-    "{user} has mentioned you in a comment on \"%s\"." : "{user} 在 “%s” 的意見中提到了您。",
+    "{user} has mentioned you in a comment on {deck-card}." : "{user} 在 {deckcard} 的意見中提到了您。",
     "The board \"%s\" has been shared with you by %s." : "面板 \"%s\" 已由 %s 分享給您。",
-    "{user} has shared the board %s with you." : "{user} 分享面板 %s 給您。",
+    "{user} has shared {deck-board} with you." : "{user} 分享了面板 {deck-board} 給您。",
+    "Card comments" : "卡片意見",
+    "%s on %s" : "%s上%s",
     "No data was provided to create an attachment." : "未能提供數據以創建附件",
     "Finished" : "完成",
     "To review" : "待審閱",
@@ -112,8 +115,8 @@ OC.L10N.register(
     "Select a list" : "選擇一個列表",
     "Card title" : "卡片標題",
     "Cancel" : "取消",
-    "Creating the new card…" : "正在建立新卡片...",
-    "\"{card}\" was added to \"{board}\"" : "\"{card}\" 已添加到 \"{board}\"",
+    "Creating the new card …" : "正在建立新卡片...",
+    "Card \"{card}\" was added to \"{board}\"" : "\"{card}\" 已添加到 \"{board}\"",
     "Open card" : "打開卡片",
     "Close" : "關閉",
     "Create card" : "建立卡片",
@@ -197,6 +200,7 @@ OC.L10N.register(
     "Created" : "建立於",
     "The title cannot be empty." : "標題不能為空。",
     "No comments yet. Begin the discussion!" : "尚無意見，開始討論吧！",
+    "Failed to load comments" : "無法加載評論",
     "Assign a tag to this card…" : "為該卡片分配標籤…",
     "Assign to users" : "指派給用戶",
     "Assign to users/groups/circles" : "指派給用戶/群組/圈子",
@@ -209,6 +213,7 @@ OC.L10N.register(
     "The comment cannot be empty." : "意見不能為空。",
     "The comment cannot be longer than 1000 characters." : "意見不能超過 1000 個字符。",
     "In reply to" : "回覆",
+    "Cancel reply" : "取消回覆",
     "Reply" : "回覆",
     "Update" : "更新",
     "Description" : "描述",
@@ -221,7 +226,7 @@ OC.L10N.register(
     "Write a description …" : "寫一段描述",
     "Choose attachment" : "選擇附件",
     "(group)" : "（群組）",
-    "(circle)" : "（圈子）",
+    "{count} comments, {unread} unread" : "{count} 條評論，{unread} 條未讀",
     "Assign to me" : "指派給我",
     "Unassign myself" : "自己解除指派",
     "Move card" : "移動卡片",
@@ -261,6 +266,8 @@ OC.L10N.register(
     "Tomorrow" : "明日",
     "This week" : "本星期",
     "No due" : "沒有到期的",
+    "Search for {searchQuery} in all boards" : "在所有面板中搜索 {searchQuery}",
+    "No results found" : "沒有結果",
     "No upcoming cards" : "沒有快將到期的卡片",
     "upcoming cards" : "快將到期的卡片",
     "Link to a board" : "連結到面板",
