@@ -70,12 +70,15 @@ OC.L10N.register(
     "Upcoming cards" : "接下來的卡片",
     "Personal" : "個人",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "卡片「%s」位於「%s」已由 %s 分配給您。",
-    "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} 已分配卡片「%s」位於「%s」給您。",
+    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} 已將位於 {deck-board} 的 {deck-card} 卡片分配給您。",
     "The card \"%s\" on \"%s\" has reached its due date." : "卡片「%s」位於「%s」已達到期日。",
+    "The card {deck-card} on {deck-board} has reached its due date." : "位於 {deck-board} 的 {deck-card} 卡片已達其到期日。",
     "%s has mentioned you in a comment on \"%s\"." : "%s 在「%s」的留言中提到了您。",
-    "{user} has mentioned you in a comment on \"%s\"." : "{user} 在「%s」的留言中提到了您。",
+    "{user} has mentioned you in a comment on {deck-card}." : "{user} 在 {deck-card} 的留言中提及您。",
     "The board \"%s\" has been shared with you by %s." : "佈告欄「%s」已由 %s 分享給您。",
-    "{user} has shared the board %s with you." : "{user} 已與您分享佈告欄 %s。",
+    "{user} has shared {deck-board} with you." : "{user} 已與您分享 {deck-board}。",
+    "Card comments" : "卡片留言",
+    "%s on %s" : "%s 在 %s",
     "No data was provided to create an attachment." : "沒有提供用於建立附件的資料。",
     "Finished" : "已完成",
     "To review" : "待檢閱",
@@ -112,8 +115,8 @@ OC.L10N.register(
     "Select a list" : "選取列表",
     "Card title" : "卡片標題",
     "Cancel" : "取消",
-    "Creating the new card…" : "正在建立新卡片……",
-    "\"{card}\" was added to \"{board}\"" : "「{card}」已新增至「{board}」",
+    "Creating the new card …" : "正在建立新卡片……",
+    "Card \"{card}\" was added to \"{board}\"" : "卡片「{card}」已新增至「{board}」",
     "Open card" : "開啟卡片",
     "Close" : "關閉",
     "Create card" : "建立卡片",
@@ -197,6 +200,7 @@ OC.L10N.register(
     "Created" : "已新增",
     "The title cannot be empty." : "標題不能為空",
     "No comments yet. Begin the discussion!" : "暫無留言。開始討論吧！",
+    "Failed to load comments" : "載入留言失敗",
     "Assign a tag to this card…" : "分配標籤到此卡片……",
     "Assign to users" : "分配給使用者",
     "Assign to users/groups/circles" : "分配給使用者／群組／小圈圈",
@@ -209,6 +213,7 @@ OC.L10N.register(
     "The comment cannot be empty." : "留言不能為空。",
     "The comment cannot be longer than 1000 characters." : "留言不能多於 1000 個字元。",
     "In reply to" : "回覆",
+    "Cancel reply" : "取消回覆",
     "Reply" : "回覆",
     "Update" : "更新",
     "Description" : "描述",
@@ -221,7 +226,7 @@ OC.L10N.register(
     "Write a description …" : "編寫描述……",
     "Choose attachment" : "選擇附件",
     "(group)" : "（群組）",
-    "(circle)" : "（小圈圈）",
+    "{count} comments, {unread} unread" : "{count} 則留言，{unread} 則未讀",
     "Assign to me" : "分配給我",
     "Unassign myself" : "取消分配給我",
     "Move card" : "移動卡片",
@@ -261,6 +266,8 @@ OC.L10N.register(
     "Tomorrow" : "明天",
     "This week" : "本週",
     "No due" : "無到期日",
+    "Search for {searchQuery} in all boards" : "在所有佈告欄中搜尋 {searchQuery}",
+    "No results found" : "找不到結果",
     "No upcoming cards" : "無接下來的卡片",
     "upcoming cards" : "接下來的卡片",
     "Link to a board" : "連結到佈告欄",
