@@ -37,7 +37,7 @@ class AQueryParameter {
 	
 	public function getValue() {
 		if (is_string($this->value) && mb_strlen($this->value) > 1) {
-			$param = ($this->value[0] === '"' && $this->value[mb_strlen($this->value) - 1] === '"') ? mb_substr($this->value, 1, -1): $this->value;
+			$param = (mb_substr($this->value, 0, 1) === '"' && mb_substr($this->value, -1, 1) === '"') ? mb_substr($this->value, 1, -1): $this->value;
 			return $param;
 		}
 		return $this->value;
